@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: authenticate
 version: 1.3.3
-id: authenticate-1.3.3-8bfd9d9af351074d4824dfaf64857f58
-key: authe_DvMOSDNjynND2oIE9fy4RA
+id: authenticate-1.3.3-53ea91e5c026eab440060c4bf4b2b35c
+key: authe_79qzWMDb1Zw1KNHdw2uGY1
 license: BSD3
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -23,26 +23,26 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/authenticate-1.3.3
-hs-libraries: HSauthenticate-1.3.3-DvMOSDNjynND2oIE9fy4RA
+hs-libraries: HSauthenticate-1.3.3-79qzWMDb1Zw1KNHdw2uGY1
 depends:
-    aeson-0.10.0.0-3aa334e096178e3f732c7fe0cfda35e7
+    aeson-0.11.1.0-9c8ef4d36b55b55b3762b9041f2dfc23
     attoparsec-0.13.0.1-cc18275e376dae94cc21e54b8b072afd
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     case-insensitive-1.2.0.5-6669cd7a393ccedc4f66c0a01b6f0e2f
-    conduit-1.2.6.2-e9736ac2851958c9940f374454cdc4fe
+    conduit-1.2.6.3-0e2837c15036cd2e0c379e7f893dd487
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    http-conduit-2.1.8-b9e39b39a9098cc832013cbf6ff75355
+    http-conduit-2.1.8-76c320bb56047f4b6951f7d6a8e71998
     http-types-0.9-d392878af9c5e1b1993961dc71a9e177
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
     network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
-    resourcet-1.1.7.2-b95e5d14f30eaa21587bc62eeb9aed0c
-    tagstream-conduit-0.5.5.3-5116d743e8946a7a525b2d26c8dd3698
+    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
+    tagstream-conduit-0.5.5.3-8fa377501d8cf106e7f32f768f3613df
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
-    xml-conduit-1.3.3.1-daddc82b56f1f7b1ac0bd9d16f4322ab
+    xml-conduit-1.3.4-929e1b83c5cd543381c444e44eb0de12
 haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
 haddock-html: /usr/share/doc/haskell-authenticate/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
